==> kubernetes-model-1.0.40-sources.jar: io/fabric8/kubernetes/api/model/VolumeMountFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class VolumeMountFluentImpl<T extends VolumeMountFluent<T>> extends BaseFluent<T> implements VolumeMountFluent<T>{

     String mountPath;     String name;     Boolean readOnly;     Map<String, Object> additionalProperties = new HashMap();
public VolumeMountFluentImpl(){
    
}
public VolumeMountFluentImpl( VolumeMount instance ){
    this.withMountPath(instance.getMountPath()); this.withName(instance.getName()); this.withReadOnly(instance.getReadOnly()); 
}

    public String getMountPath(){
    return this.mountPath;
    }
    public T withMountPath( String mountPath){
    this.mountPath=mountPath; return (T) this;
    }
    public String getName(){
    return this.name;
    }
    public T withName( String name){
    this.name=name; return (T) this;
    }
    public Boolean isReadOnly(){
    return this.readOnly;
    }
    public T withReadOnly( Boolean readOnly){
    this.readOnly=readOnly; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
VolumeMountFluentImpl that = (VolumeMountFluentImpl) o;
if (mountPath != null ? !mountPath.equals(that.mountPath) :that.mountPath != null) return false;
if (name != null ? !name.equals(that.name) :that.name != null) return false;
if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.50-sources.jar: io/fabric8/kubernetes/api/model/VolumeMountFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class VolumeMountFluentImpl<A extends VolumeMountFluent<A>> extends BaseFluent<A> implements VolumeMountFluent<A>{

     String mountPath;     String name;     Boolean readOnly;
public VolumeMountFluentImpl(){
    
}
public VolumeMountFluentImpl( VolumeMount instance ){
    this.withMountPath(instance.getMountPath()); this.withName(instance.getName()); this.withReadOnly(instance.getReadOnly()); 
}

    public String getMountPath(){
    return this.mountPath;
    }
    public A withMountPath( String mountPath){
    this.mountPath=mountPath; return (A) this;
    }
    public String getName(){
    return this.name;
    }
    public A withName( String name){
    this.name=name; return (A) this;
    }
    public Boolean isReadOnly(){
    return this.readOnly;
    }
    public A withReadOnly( Boolean readOnly){
    this.readOnly=readOnly; return (A) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
VolumeMountFluentImpl that = (VolumeMountFluentImpl) o;
if (mountPath != null ? !mountPath.equals(that.mountPath) :that.mountPath != null) return false;
if (name != null ? !name.equals(that.name) :that.name != null) return false;
if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
return true;

    }



}
